[90f5e61] master: Proxied → Proxified

Sybren A. Stüvel noreply at git.blender.org
Fri Oct 7 13:33:46 CEST 2016


Commit: 90f5e61b72550bfe1e371626e99d3342214ce7ff
Author: Sybren A. Stüvel
Date:   Fri Oct 7 13:33:43 2016 +0200
Branches: master
https://developer.blender.org/rB90f5e61b72550bfe1e371626e99d3342214ce7ff

Proxied → Proxified

===================================================================

M	source/blender/blenkernel/intern/library.c

===================================================================

diff --git a/source/blender/blenkernel/intern/library.c b/source/blender/blenkernel/intern/library.c
index 2d444a6..c66ac31 100644
--- a/source/blender/blenkernel/intern/library.c
+++ b/source/blender/blenkernel/intern/library.c
@@ -1725,10 +1725,10 @@ void BKE_library_make_local(Main *bmain, const Library *lib, const bool untagged
 						Object *ob = (Object *)id;
 						Object *ob_new = (Object *)id->newid;
 
 						/* Proxies only work when the proxied object is linked-in from a library. */
 						if (ob->proxy->id.lib == NULL) {
 							printf("Warning, proxy object %s will loose its link to %s, because the "
-							       "proxied object is local.\n", id->newid->name, ob->proxy->id.name);
+							       "proxified object is local.\n", id->newid->name, ob->proxy->id.name);
 						}
 						/* We can only switch the proxy'ing to a made-local proxy if it is no longer
 						 * referred to from a library. Not checking for local use; if new local proxy
@@ -1725,10 +1725,10 @@ void BKE_library_make_local(Main *bmain, const Library *lib, const bool untagged
 						Object *ob_new = (Object *)id->newid;
 
-						/* Proxies only work when the proxied object is linked-in from a library. */
+						/* Proxies only work when the proxified object is linked-in from a library. */
 						if (ob->proxy->id.lib == NULL) {
 							printf("Warning, proxy object %s will loose its link to %s, because the "




More information about the Bf-blender-cvs mailing list